Plotting and Visualization
==========================

These modules provide specialized tools for plotting data related to fNIRS
analysis, including functions for visualizing scalp plots, sensitivity matrices,
and optode montages.

.. autosummary::
   :toctree: _autosummary_models
   :recursive:

    cedalion.plots
    cedalion.vis.plot_probe
    cedalion.vis.plot_sensitivity_matrix
    cedalion.vis.time_series

Examples
--------

.. nbgallery::
   :glob:

   ../examples/plots_visualization/*